console

package
v0.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 14, 2026 License: MIT Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AudioIO

type AudioIO struct {
	// contains filtered or unexported fields
}

AudioIO manages bidirectional audio interfacing with the host OS's microphone and speakers.

func NewAudioIO

func NewAudioIO() *AudioIO

func (*AudioIO) MicFrames

func (a *AudioIO) MicFrames() <-chan *model.AudioFrame

func (*AudioIO) PushFrame

func (a *AudioIO) PushFrame(frame *model.AudioFrame)

PushFrame takes audio from the Agent and queues it for the speakers

func (*AudioIO) Start

func (a *AudioIO) Start(ctx context.Context) error

func (*AudioIO) Stop

func (a *AudioIO) Stop() error

func (*AudioIO) Write

func (a *AudioIO) Write(frame *model.AudioFrame) error

Write for pipe integration

type ConsoleModel

type ConsoleModel struct {
	// contains filtered or unexported fields
}

ConsoleModel drives the interactive terminal UI

func NewConsoleModel

func NewConsoleModel(ctx context.Context, audioIO *AudioIO) *ConsoleModel

func (*ConsoleModel) Init

func (m *ConsoleModel) Init() tea.Cmd

func (*ConsoleModel) Update

func (m *ConsoleModel) Update(msg tea.Msg) (tea.Model, tea.Cmd)

func (*ConsoleModel) View

func (m *ConsoleModel) View() string

Jump to